@@ -313,6 +313,10 @@ class DetectTest(unittest.TestCase):
     def tearDown(self):
         shutil.rmtree(self.plugin_dir)
 
+        # most test cases switch the apt root, so the apt.Cache() cache becomes
+        # unreliable; reset it
+        UbuntuDrivers.detect.packages_for_modalias.cache_maps = {}
+
     @unittest.skipUnless(os.path.isdir('/sys/devices'), 'no /sys dir on this system')
     def test_system_modaliases_system(self):
         '''system_modaliases() for current system'''
@@ -345,7 +349,10 @@ class DetectTest(unittest.TestCase):
 
         sec = (stop.ru_utime + stop.ru_stime) - (start.ru_utime + start.ru_stime)
         sys.stderr.write('[%.2f s] ' % sec)
-        self.assertLess(sec, 30.0)
+        if 'arm' in os.uname().machine:
+            self.assertLess(sec, 90.0)
+        else:
+            self.assertLess(sec, 30.0)
 
     def test_system_driver_packages_chroot(self):
         '''system_driver_packages() for test package repository'''
